const canvas = document.getElementById("gameCanvas");
const ctx = canvas.getContext("2d");
const resetButton = document.getElementById("resetButton");
const scoreHolder = document.getElementById("score");
canvas.width = 800;
canvas.height = 600;
let snake = [];
let snakeLength = 50;
let speed = 2;
let score = 0;
let loopId;
let delta = .5;
let cellSize = 10;

function createSnake() {
  snake[0] = {
    x: canvas.width / 2,
    y: canvas.height / 2
  };
}
function drawSnake() {
  for (let i = 0; i < snake.length; i++) {
    ctx.fillStyle = "green";
    ctx.fillRect(snake[i].x - cellSize, snake[i].y - cellSize, cellSize, cellSize);
  }
}

let food = {
    x: 0,
    y: 0
  };
  
  function createFood() {
    food.x = Math.floor(Math.random() * (canvas.width - 10) + 10);
    food.y = Math.floor(Math.random() * (canvas.height - 10) + 10);
  }
  
  function drawFood() {
    ctx.fillStyle = "red";
    ctx.fillRect(food.x - cellSize, food.y - cellSize, cellSize, cellSize);
  }

  let direction = "right";

document.addEventListener("keydown", changeDirection);

function changeDirection(e) {
  if (e.keyCode == 37 && direction != "right") {
    direction = "left";
  } else if (e.keyCode == 38 && direction != "down") {
    direction = "up";
  } else if (e.keyCode == 39 && direction != "left") {
    direction = "right";
  } else if (e.keyCode == 40 && direction != "up") {
    direction = "down";
  }
}

function moveSnake() {
  let headX = snake[0].x;
  let headY = snake[0].y;

  if (direction == "right") {
    headX += delta * speed;
  } else if (direction == "left") {
    headX -= delta * speed;
  } else if (direction == "up") {
    headY -= delta * speed;
  } else if (direction == "down") {
    headY += delta * speed;
  }

  let newHead = {
    x: headX,
    y: headY
  };

  snake.unshift(newHead);

  if (snake.length > snakeLength) {
    snake.pop();
  }
}

function checkCollisions() {
    // Check if snake toutch the walls
    if (snake[0].x < cellSize || snake[0].x > canvas.width ||
        snake[0].y < cellSize || snake[0].y > canvas.height) {
      // Game over
      alert("انتهت اللعبة واحرزت  " + score);
      resetGame();
      cancelAnimationFrame(loopId);
      return;
    }
  
    // Check if snake hits its own body
    for (let i = 1; i < snake.length; i++) {
      if (snake[0].x == snake[i].x && snake[0].y == snake[i].y) {
        // Game over
        alert("انتهت اللعبة واحرزت  " + score);
        resetGame();
        cancelAnimationFrame(loopId);
        return;
      }
    }
  
    // Check if snake eats the food
    if (snake[0].x >= food.x - 10 && snake[0].x <= food.x + 10 &&
        snake[0].y >= food.y - 10 && snake[0].y <= food.y + 10) {
      // Increase the snake's length and generate a new food pellet
      snakeLength+=50;
      createFood();
      score++;
      // Increase the snake's speed every 5 points
      if (score % 5 === 0) {
        speed += 1;
      }
      scoreHolder.innerHTML = score;
    }
  }
  function clearCanvas() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
  }
  function gameLoop() {
    clearCanvas();
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    moveSnake();
    drawSnake();
    checkCollisions();
    drawFood();
    loopId = requestAnimationFrame(gameLoop);
  }
  function resetGame() {
    snake = [];
    speed = 1;
    snakeLength = 50;
    createSnake();
    createFood();
    score = 0;
    snake[0].x = canvas.width / 2;
    snake[0].y = canvas.height / 2;
    clearCanvas();
    gameLoop();
  }
  // on page load start the game
window.onload = function() {
    createSnake();
    createFood();
    gameLoop();
};  
resetButton.addEventListener("click", resetGame );